The 52-Week Low Club for Monday - VIVUS, Inc. (NASDAQ:VVUS) - 24/7 Wall St.
Description: Source: ThinkstockDecember 28, 2014: Here are four stocks among the 66 equities making new 52-week lows today. Volumes continue to be low as we wait to ring in the new year. Transocean Partners LLC (NYSE: RIGP) posted a new 52-week — and all-time — low on Monday of $13.18. Based on Friday night’s closing price […]
Keywords: Investing, VVUS, VVUS stock, VVUS ticker, VVUS news, Corporate Performance

24/7 Wall St. - Insightful Analysis and Commentary for U.S. and Global Equity Investors
Free Daily Newsletter
Terms & Conditions

# The 52-Week Low Club for Monday

By Paul Ausick December 29, 2014 4:11 pm EST

Print
Email
Tweet

December 28, 2014: Here are four stocks among the 66 equities making new 52-week lows today. Volumes continue to be low as we wait to ring in the new year.

Transocean Partners LLC (NYSE: RIGP) posted a new 52-week — and all-time — low on Monday of $13.18. Based on Friday night’s closing price of $14.32 that’s a drop of nearly 8%. The stock’s 52-week high is $29.43. Volume is about a third higher than the daily average of around 325,000 shares. The offshore drilling firm had no specific news today, but crude prices are down about 2%.

SandRidge Mississippian Trust II (NYSE: SDR) dropped about 5.3% on Monday to post a new 52-week — and all-time — low of $3.91 after closing at $4.13 on Wednesday. The stock’s 52-week high is $10.12. Share volume is nearly double the daily average of 400,000 shares traded. The royalty company had no specific news today but is feeling pressure from low crude prices.

Vivus Inc. (NASDAQ: VVUS) dropped about 6% Monday to post a new 52-week low of $2.78. The stock’s 52-week high is $9.80. Volume totaled 25% higher than the daily average of around 1.9 million shares. The U.S. FDA approved a competing diabetes drug last week to compete with Vivus’s Qsymia treatment.

Zulilly Inc. (NASDAQ: ZU) dropped about 3.8% Monday to establish a new 52-week — and all-time — low at $22.39 against a high of $73.50. Volume was 25% below the daily average of around 1.4 million shares. The online retailer had no specific news today.

ALSO READ: States Where People Live Longest

By Paul Ausick

Buzz up! Digg Fark Facebook Reddit Tumblr
Read more: Investing, Corporate Performance, VIVUS, Inc. (NASDAQ:VVUS)
comments powered by Disqus

- ### Recent Posts

  - The 52-Week Low Club for Friday
  - The 4 Stocks That Weighed Down the DJIA Friday
  - GM Closes Out 2014 With Total 84 Recalls for 30 Million Vehicles
  - Can India Outperform Again in 2015?
  - Casino Stocks Hammered on Macau Data
  - Apple Gets First Analyst Price Target Hike of 2015
  - November New Construction Spending Unexpectedly Drops
  - What Terminating Licenses Will Mean for Ballard Power
  - Russian Oil Production Sets Post-Soviet High
  - Why Wells Fargo 2015 Semiconductor Outlook Is Optimistic but Cautious
- Get Quote for:
  Symbol Lookup
  Search

x